# EMnify Python SDK
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=EMnify_emnify-sdk-python&metric=reliability_rating&token=cb362b064422f10be97244bb527b8bc37e1378b4)](https://sonarcloud.io/summary/new_code?id=EMnify_emnify-sdk-python)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=EMnify_emnify-sdk-python&metric=coverage&token=cb362b064422f10be97244bb527b8bc37e1378b4)](https://sonarcloud.io/summary/new_code?id=EMnify_emnify-sdk-python)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=EMnify_emnify-sdk-python&metric=sqale_rating&token=cb362b064422f10be97244bb527b8bc37e1378b4)](https://sonarcloud.io/summary/new_code?id=EMnify_emnify-sdk-python)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=EMnify_emnify-sdk-python&metric=security_rating&token=cb362b064422f10be97244bb527b8bc37e1378b4)](https://sonarcloud.io/summary/new_code?id=EMnify_emnify-sdk-python)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=EMnify_emnify-sdk-python&metric=bugs&token=cb362b064422f10be97244bb527b8bc37e1378b4)](https://sonarcloud.io/summary/new_code?id=EMnify_emnify-sdk-python)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=EMnify_emnify-sdk-python&metric=vulnerabilities&token=cb362b064422f10be97244bb527b8bc37e1378b4)](https://sonarcloud.io/summary/new_code?id=EMnify_emnify-sdk-python)

Supply your swarm of IoT Devices with cloud connectivity by [EMnify](https://emnify.com).
Automate your routines with this SDK for Python.  

## Installation

`Python > 3.6` is **required**.

- Install from source
```shell
git clone https://github.com/emnify-python-sdk.git emnify-sdk
cd emnify-sdk
python setup.py install
```
- or install with pip
```shell
pip install emnify-sdk
```

## Documentation

Documentation is available on the [EMnify Python SDK docs site](https://emnify.github.io/emnify-sdk-python/).

## Getting Help and Contribute

Visit [Help Section](https://emnify.github.io/emnify-sdk-python/help.html).
